@@ -10,5 +10,6 @@ utils::globalVariables(
       ".model_table", ".model_table_clean", ".residuals", ".is_null", ".",
       ".final_values", ".idx_values", ".pred_values", ".row_id", "..row_id", "rowid..",
       "id", ".id", "this_model", "wflow_id", "rowid", "value.x", "value.y",
-      "..rowid")
+      "..rowid", ".actual_data", "n", ".modeltime_tables", ".error_desc",
+      "x", "d", "f", ".forecast")
 )
