@@ -14,7 +14,7 @@ test_that("extended_forecast_accuracy_metric_set works", {
     )
 
     # Create a metric summarizer function from the metric set
-    calc_default_metrics <- extended_forecast_accuracy_metric_set(mae)
+    calc_default_metrics <- extended_forecast_accuracy_metric_set(yardstick::mae)
 
     # Apply the metric summarizer to new data
     ret <- calc_default_metrics(data, y, y_hat)
